==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerTlsFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface KafkaListenerTlsFluent<A extends KafkaListenerTlsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public TlsListenerConfiguration getConfiguration();
    public TlsListenerConfiguration buildConfiguration();
    public A withConfiguration(TlsListenerConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> withNewConfigurationLike(TlsListenerConfiguration item);
    public KafkaListenerTlsFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> editOrNewConfigurationLike(TlsListenerConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsListenerConfigurationFluent<KafkaListenerTlsFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/listener/KafkaListenerTlsFluent.java <==
package io.strimzi.api.kafka.model.listener;

import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface KafkaListenerTlsFluent<A extends KafkaListenerTlsFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAuth instead.
 * @return The buildable object.
 */
@Deprecated public KafkaListenerAuthentication getAuth();
    public KafkaListenerAuthentication buildAuth();
    public A withAuth(KafkaListenerAuthentication auth);
    public Boolean hasAuth();
    public A withKafkaListenerAuthenticationOAuth(KafkaListenerAuthenticationOAuth kafkaListenerAuthenticationOAuth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<A> withNewKafkaListenerAuthenticationOAuthLike(KafkaListenerAuthenticationOAuth item);
    public A withKafkaListenerAuthenticationTlsAuth(KafkaListenerAuthenticationTls kafkaListenerAuthenticationTlsAuth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<A> withNewKafkaListenerAuthenticationTlsAuthLike(KafkaListenerAuthenticationTls item);
    public A withKafkaListenerAuthenticationScramSha512Auth(KafkaListenerAuthenticationScramSha512 kafkaListenerAuthenticationScramSha512Auth);
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512Auth();
    public KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<A> withNewKafkaListenerAuthenticationScramSha512AuthLike(KafkaListenerAuthenticationScramSha512 item);
    public A addToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A setToNetworkPolicyPeers(int index,NetworkPolicyPeer item);
    public A addToNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A addAllToNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public A removeFromNetworkPolicyPeers(NetworkPolicyPeer... items);
    public A removeAllFromNetworkPolicyPeers(Collection<NetworkPolicyPeer> items);
    public java.util.List<NetworkPolicyPeer> getNetworkPolicyPeers();
    public NetworkPolicyPeer getNetworkPolicyPeer(int index);
    public NetworkPolicyPeer getFirstNetworkPolicyPeer();
    public NetworkPolicyPeer getLastNetworkPolicyPeer();
    public NetworkPolicyPeer getMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public Boolean hasMatchingNetworkPolicyPeer(io.fabric8.kubernetes.api.builder.Predicate<NetworkPolicyPeer> predicate);
    public A withNetworkPolicyPeers(java.util.List<NetworkPolicyPeer> networkPolicyPeers);
    public A withNetworkPolicyPeers(NetworkPolicyPeer... networkPolicyPeers);
    public Boolean hasNetworkPolicyPeers();
    
/**
 * This method has been deprecated, please use method buildConfiguration instead.
 * @return The buildable object.
 */
@Deprecated public TlsListenerConfiguration getConfiguration();
    public TlsListenerConfiguration buildConfiguration();
    public A withConfiguration(TlsListenerConfiguration configuration);
    public Boolean hasConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> withNewConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> withNewConfigurationLike(TlsListenerConfiguration item);
    public KafkaListenerTlsFluent.ConfigurationNested<A> editConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> editOrNewConfiguration();
    public KafkaListenerTlsFluent.ConfigurationNested<A> editOrNewConfigurationLike(TlsListenerConfiguration item);

    public interface KafkaListenerAuthenticationOAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationOAuthFluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationOAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationOAuth();
}
    public interface KafkaListenerAuthenticationTlsAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationTlsFluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationTlsAuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationTlsAuth();
}
    public interface KafkaListenerAuthenticationScramSha512AuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaListenerAuthenticationScramSha512Fluent<KafkaListenerTlsFluent.KafkaListenerAuthenticationScramSha512AuthNested<N>>{

        
    public N and();    public N endKafkaListenerAuthenticationScramSha512Auth();
}
    public interface ConfigurationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsListenerConfigurationFluent<KafkaListenerTlsFluent.ConfigurationNested<N>>{

        
    public N and();    public N endConfiguration();
}


}
